@@ -4,5 +4,5 @@ from hurry.resource import ResourceInclusion, GroupInclusion
 
 from megrok.resource.directives import include, use_hash, resource
 from megrok.resource.components import Library, ResourceLibrary
-from megrok.resource.components import IResourcesIncluder, ILibrary
+from megrok.resource.interfaces import IResourcesIncluder, ILibrary
 from megrok.resource.utils import component_includes
